@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -21,9 +21,11 @@
 
 #include <qtest.h>
 #include <QDir>
+#include <QPalette>
 #include <QProcess>
 #include <QStandardPaths>
 
+#include <KColorScheme>
 #include <KConfigGroup>
 #include <KSharedConfig>
 
@@ -173,6 +175,7 @@ void GrantleeThemeTest::testRenderTemplate_data()
 
     QTest::newRow("valid theme") << QStringLiteral("valid") << true << QStringLiteral("filename.testdesktop") << QStringLiteral("header");
     QTest::newRow("invalid theme") << QStringLiteral("invalid") << false << QStringLiteral("filename.testdesktop") << QString();
+    QTest::newRow("color") << QStringLiteral("color") << true << QStringLiteral("color.testdesktop") << QStringLiteral("color");
 }
 
 void GrantleeThemeTest::testRenderTemplate()
@@ -191,6 +194,14 @@ void GrantleeThemeTest::testRenderTemplate()
     data[QStringLiteral("title")] = QStringLiteral("Something's going on");
     data[QStringLiteral("subtext")] = QStringLiteral("Please wait, it will be over soon.");
 
+    QPalette pal;
+    pal.setColor(QPalette::Button, Qt::red);
+    pal.setColor(QPalette::Active, QPalette::Base, Qt::red);
+    pal.setColor(QPalette::Inactive, QPalette::Base, Qt::green);
+    pal.setColor(QPalette::Disabled, QPalette::Base, Qt::blue);
+    data[QStringLiteral("pal")] = QVariant::fromValue(pal);
+    data[QStringLiteral("colorScheme")] = QVariant::fromValue(KColorScheme(QPalette::Normal, KColorScheme::View));
+
     GrantleeTheme::Theme theme(themePath, dirname, filename);
     QCOMPARE(theme.isValid(), isValid);
 
